pub(crate) async fn show_peer_info(
__arg0: Path<DestinationParams>,
__arg1: State<Arc<InternalState>>,
) -> impl IntoResponseExpand description
Returns transport-related information about the given peer.
This includes the peer ids that the given peer has announced on-chain
and peer ids that are actually observed by the transport layer.